@@ -1288,6 +1288,27 @@ real_draw_box (GtkStyle      *style,
 
   sanitize_size (window, &width, &height);
 
+  /* None of the drawing routines below are set up to handle SHADOW_TYPE_NONE,
+   * so just fill in a blank box here.  Ideally everything in the theme
+   * would be reworked to handle SHADOW_TYPE_NONE correctly */
+  if (shadow_type == GTK_SHADOW_NONE) {
+    if (!style->bg_pixmap[state_type] ||
+	GDK_IS_PIXMAP (window)) {
+	if (area)
+	  gdk_gc_set_clip_rectangle (style->bg_gc[state_type], area);
+	
+	gdk_draw_rectangle (window, style->bg_gc[state_type], TRUE,
+			    x, y, width, height);
+	if (area)
+	  gdk_gc_set_clip_rectangle (style->bg_gc[state_type], NULL);
+    }
+    else
+      gtk_style_apply_default_background (style, window,
+					  widget && !GTK_WIDGET_NO_WINDOW (widget),
+					  state_type, area, x, y, width, height);
+    return;
+  }
+
   if (DETAIL("button") ||
       DETAIL("togglebutton")) {
     /*
@@ -1427,7 +1448,7 @@ real_draw_box (GtkStyle      *style,
     }
 
     /* Only draw shadow if button is large enough to fit it. */
-    if (width > 18 && height > 18 && shadow_type != GTK_SHADOW_NONE) {
+    if (width > 18 && height > 18) {
 
       /* Offset shadow if depressed. */
       if (state_type == GTK_STATE_ACTIVE) {
@@ -1586,7 +1607,7 @@ real_draw_box (GtkStyle      *style,
 
 #if 1
     /* Remove this to add the shadow back for depressed buttons. */
-    if (GTK_WIDGET_STATE (widget) == GTK_STATE_ACTIVE || shadow_type == GTK_SHADOW_NONE)
+    if (GTK_WIDGET_STATE (widget) == GTK_STATE_ACTIVE)
       return;
 #endif
 
@@ -1758,18 +1779,27 @@ real_draw_box (GtkStyle      *style,
     GdkGC *fg_gc = get_gc (style, &style->bg[state_type], &style->fg[state_type], STANDARD_BORDER_SHADE);
     GdkColor *fg_color = get_color (style, &style->bg[state_type], &style->fg[state_type], STANDARD_BORDER_SHADE);
     GdkGC *corner_gc = get_gc (style, &style->bg[state_type], fg_color, SHADE_HALF);
-    int indicator_width;
+    int indicator_width, vline_x;
 
     draw_rounded_rect_two_pixel (window, bg_gc, fg_gc, corner_gc,
 				 area, x, y, width, height);
 
     indicator_width = option_menu_get_indicator_width (widget);
 
+#if INDUSTRIAL_GTK_VERSION == 2
+    if ((!widget) || (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR))
+      vline_x = x + width - indicator_width - GET_XTHICKNESS(style) + 1;
+    else
+      vline_x = x + indicator_width + GET_XTHICKNESS(style) - 1;
+#else
+    vline_x = x + width - indicator_width - GET_XTHICKNESS(style) + 1;
+#endif
+      
     gtk_paint_vline (style, window, state_type, area, widget,
 		     detail,
 		     y + GET_YTHICKNESS (style) + 4,
 		     y + height - GET_YTHICKNESS(style) - 4,
-		     x + width - indicator_width - GET_XTHICKNESS(style) + 1);
+		     vline_x);
   } else /* if (DETAIL("slider") ||
 	     DETAIL("stepper") ||
 	     DETAIL("vscrollbar") ||
@@ -1789,12 +1819,8 @@ real_draw_box (GtkStyle      *style,
     GdkColor *fg_color = get_color (style, &style->bg[state_type], &style->fg[state_type], STANDARD_BORDER_SHADE);
     GdkGC *corner_gc = get_gc (style, &style->bg[state_type], fg_color, SHADE_HALF);
 
-    if(shadow_type == GTK_SHADOW_NONE) {
-      if(bg_gc)
-	gdk_draw_rectangle (window, bg_gc, TRUE, x, y, width, height);
-    } else {
-      draw_rounded_rect_one_pixel (window, bg_gc, fg_gc, corner_gc, area, x, y, width, height);
-    }
+    draw_rounded_rect_one_pixel (window, bg_gc, fg_gc, corner_gc,
+				 area, x, y, width, height);
   }
 }
 
@@ -2121,6 +2147,7 @@ draw_extension (GtkStyle       *style,
   }
 }
 
+#if INDUSTRIAL_GTK_VERSION == 1
 static void
 real_draw_arrow (GdkWindow     *window,
 		 GdkGC         *gc,
@@ -2292,6 +2319,7 @@ draw_arrow (GtkStyle      *style,
 		   area, arrow_type,
 		   x, y, width, height);
 }
+#endif
 
 static inline int
 decode_shadow (GtkShadowType shadow_type)
@@ -2403,8 +2431,8 @@ draw_option (GtkStyle		*style,
     bg = &style->bg[state_type];
   } 
 #endif
-
-  if (width <= 8)
+  
+  if (width < 13)
     which = PIXMAP_SMALL_RADIO_ACTIVE;
   else
     which = PIXMAP_RADIO_ACTIVE;
